<?php

namespace Pinpoint\FeaturesManager\Block\Adminhtml\Index;

use Magento\Backend\Block\Widget\Form\Container;

/**
 * Class Edit
 * @package Pinpoint\FeaturesManager\Block\Adminhtml\Index
 */
class Edit extends Container
{
    /**
    * Core registry
    *
    * @var \Magento\Framework\Registry
    */
    protected $_coreRegistry = null;

    /**
    * @param \Magento\Backend\Block\Widget\Context $context
    * @param \Magento\Framework\Registry $registry
    * @param array $data
    */
    public function __construct(
       \Magento\Backend\Block\Widget\Context $context,
       \Magento\Framework\Registry $registry,
       array $data = []
    ) {
        $this->_coreRegistry = $registry;
        parent::__construct($context, $data);
    }

    /**
    *
    * @return void
    */
    protected function _construct()
    {
        $this->_objectId = 'id';
        $this->_blockGroup = 'Pinpoint_FeaturesManager';
        $this->_controller = 'adminhtml_index';

        parent::_construct();

        if ($this->_isAllowedAction('Magento_Catalog::catalog')) {
            $this->buttonList->update('save', 'label', __('Save Product Feature'));
            $this->buttonList->add(
               'saveandcontinue',
               [
                   'label' => __('Save and Continue Edit'),
                   'class' => 'save',
                   'data_attribute' => [
                       'mage-init' => [
                           'button' => ['event' => 'saveAndContinueEdit', 'target' => '#edit_form'],
                       ],
                   ]
               ],
               -100
           );
        } else {
            $this->buttonList->remove('save');
        }
    }

    /**
    *
    * @return \Magento\Framework\Phrase
    */
    public function getHeaderText()
    {
        if ($this->_coreRegistry->registry('current_model')->getId()) {
            return __("Edit Product Feature '%1'", $this->escapeHtml($this->_coreRegistry->registry('current_model')->getName()));
        } else {
            return __('New Product Feature');
        }
    }

    /**
    * Check permission for passed action
    *
    * @param string $resourceId
    * @return bool
    */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }

    /**
    * Getter of url for "Save and Continue" button
    * tab_id will be replaced by desired by JS later
    *
    * @return string
    */
    protected function _getSaveAndContinueUrl()
    {
        return $this->getUrl('*/*/save', ['_current' => true, 'back' => 'edit', 'active_tab' => '']);
    }
}
