<?php

namespace Pinpoint\FeaturesManager\Block\Adminhtml\Index\Edit;

use Magento\Backend\Block\Widget\Form\Generic;

/**
 * Class Form
 * @package Pinpoint\FeaturesManager\Block\Adminhtml\Index\Edit
 */
class Form extends Generic
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;

    protected $translationCollection;

    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Store\Model\System\Store $systemStore,
        \Pinpoint\FeaturesManager\Model\ResourceModel\FeatureTranslation\Collection $translationCollection,
        array $data = []
    ) {
        $this->_systemStore = $systemStore;
        $this->translationCollection = $translationCollection;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('productfeatures_form');
        $this->setTitle(__('Product Feature Information'));
    }

    /**
     * Prepare form
     *
     * @return $this
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    protected function _prepareForm()
    {
        /** @var \Pinpoint\FeaturesManager\Model\ProductFeatures $model */
        $model = $this->_coreRegistry->registry('current_model');

        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create(
            ['data' => ['id' => 'edit_form', 'action' => $this->getData('action'), 'method' => 'post', 'enctype' => 'multipart/form-data']]
        );

        $form->setHtmlIdPrefix('productfeatures_');

        $fieldset = $form->addFieldset(
            'base_fieldset',
            ['legend' => __('General Information'), 'class' => 'fieldset-wide']
        );

        if ($model->getId()) {
            $fieldset->addField('id', 'hidden', ['name' => 'id']);
        }

        $fieldset->addField('store_id', 'hidden', ['name' => 'store_id']);

        $fieldset->addField(
            'name',
            'text',
            [
                'name' => 'name',
                'label' => __('Feature Name'),
                'title' => __('Feature Name'),
                'required' => true
            ]
        );

        if ($store = $this->getRequest()->getParam('store', 0)) {
            $storeValue = $this->translationCollection
                ->addFieldToFilter('store_id', $store)
                ->addFieldToFilter('feature_id', $model->getId())
                ->getFirstItem()
            ;

            if ($storeValue->getId()) {
                $model->setData('name', $storeValue->getData('name'));
            }

            $model->setData('store_id', $store);
        } else {
            $fieldset->addField(
                'image',
                'image',
                [
                    'label' => __('Image'),
                    'name' => 'image',
                    'previewTmpl' => 'Magento_Catalog/image-preview',
                    'elementTmpl' => 'ui/form/element/uploader/uploader',
                    'formElement' => 'fileUploader'
                ]
            );
        }

        $form->setValues($model->getData());
        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}
