<?php

namespace Pinpoint\FeaturesManager\Block;

use Magento\Catalog\Api\ProductRepositoryInterface;

/**
 * Class Features
 * @package Pinpoint\FeaturesManager\Block
 */
class Features extends \Magento\Catalog\Block\Product\View
{
    /**
     * @var \Pinpoint\FeaturesManager\Model\ResourceModel\ProductFeatures\Collection
     */
    protected $featuresCollection;

    protected $featureTranslationCollection;

    public function __construct(
        \Magento\Catalog\Block\Product\Context $context,
        \Magento\Framework\Url\EncoderInterface $urlEncoder,
        \Magento\Framework\Json\EncoderInterface $jsonEncoder,
        \Magento\Framework\Stdlib\StringUtils $string,
        \Magento\Catalog\Helper\Product $productHelper,
        \Magento\Catalog\Model\ProductTypes\ConfigInterface $productTypeConfig,
        \Magento\Framework\Locale\FormatInterface $localeFormat,
        \Magento\Customer\Model\Session $customerSession,
        ProductRepositoryInterface $productRepository,
        \Magento\Framework\Pricing\PriceCurrencyInterface $priceCurrency,
        \Pinpoint\FeaturesManager\Model\ResourceModel\ProductFeatures\Collection $featuresCollection,
        \Pinpoint\FeaturesManager\Model\ResourceModel\FeatureTranslation\Collection $featureTranslationCollection,
        array $data = []
    ) {
        parent::__construct(
            $context,
            $urlEncoder,
            $jsonEncoder,
            $string,
            $productHelper,
            $productTypeConfig,
            $localeFormat,
            $customerSession,
            $productRepository,
            $priceCurrency,
            $data
        );

        $this->featuresCollection = $featuresCollection;
        $this->featureTranslationCollection = $featureTranslationCollection;
    }

    /**
     * @return bool
     */
    public function hasFeatures()
    {
        return $this->getProduct()->getCustomAttribute('product_features') !== null;
    }

    /**
     * @return array|\Magento\Framework\DataObject[]
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getFeatures()
    {
        if ($this->hasFeatures()) {
            $features = array_filter(explode(',', $this->getProduct()->getCustomAttribute('product_features')->getValue()));
            $features = $this->featuresCollection
                ->clear()
                ->addFieldToFilter('id', ['in' => $features])
                ->load()
                ->getItems();

            $storeId = $this->_storeManager->getStore()->getId();
            foreach ($features as &$feature) {
                $collection = clone $this->featureTranslationCollection;
                $translationLookup = $collection
                    ->clear()
                    ->addFieldToFilter('store_id', $storeId)
                    ->addFieldToFilter('feature_id', $feature->getId())
                    ->getFirstItem();

                if ($translationLookup->getId()) {
                    $feature->setData('name', $translationLookup->getData('name'));
                }
            }

            return $features;
        }

        return [];
    }
}
