<?php

namespace Pinpoint\FeaturesManager\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;

/**
 * Class Delete
 * @package Pinpoint\FeaturesManager\Controller\Adminhtml\Index
 */
class Delete extends Action
{
    /**
     * @var \Pinpoint\FeaturesManager\Model\ProductFeatures
     */
    protected $_model;

    /**
     * @param Action\Context $context
     * @param \Pinpoint\FeaturesManager\Model\ProductFeatures $model
     */
    public function __construct(
        Action\Context $context,
        \Pinpoint\FeaturesManager\Model\ProductFeatures $model
    ) {
        parent::__construct($context);
        $this->_model = $model;
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Magento_Catalog::catalog');
    }

    /**
     * Delete action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                $model = $this->_model;
                $model->load($id);
                $model->delete();
                $this->messageManager->addSuccess(__('Product Feature deleted'));
                return $resultRedirect->setPath('*/*/');
            } catch (\Exception $e) {
                $this->messageManager->addError($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', ['id' => $id]);
            }
        }
        $this->messageManager->addError(__('Product Feature does not exist'));
        return $resultRedirect->setPath('*/*/');
    }
}