<?php

namespace Pinpoint\FeaturesManager\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;
use Magento\Framework\App\Filesystem\DirectoryList;

/**
 * Class Save
 * @package Pinpoint\FeaturesManager\Controller\Adminhtml\Index
 */
class Save extends Action
{
    /**
     * @var \Pinpoint\FeaturesManager\Model\ProductFeatures
     */
    protected $_model;

    /**
     * @var \Pinpoint\FeaturesManager\Model\FeatureTranslation
     */
    protected $featureTranslation;

    /**
     * @var \Pinpoint\FeaturesManager\Model\ResourceModel\FeatureTranslation\Collection
     */
    protected $featureTranslationCollection;

    /**
     * @var \Magento\Framework\Filesystem
     */
    protected $filesystem;

    /**
     * @var \Magento\Framework\Filesystem\Driver\File
     */
    protected $file;

    /**
     * @var \Magento\MediaStorage\Model\File\UploaderFactory
     */
    protected $fileUploaderFactory;

    /**
     * Save constructor.
     * @param Action\Context $context
     * @param \Pinpoint\FeaturesManager\Model\ProductFeatures $model
     * @param \Pinpoint\FeaturesManager\Model\FeatureTranslation $featureTranslation
     * @param \Pinpoint\FeaturesManager\Model\ResourceModel\FeatureTranslation\Collection $featureTranslationCollection
     * @param \Magento\Framework\Filesystem $filesystem
     * @param \Magento\Framework\Filesystem\Driver\File $file
     * @param \Magento\MediaStorage\Model\File\UploaderFactory $fileUploaderFactory
     */
    public function __construct(
        Action\Context $context,
        \Pinpoint\FeaturesManager\Model\ProductFeatures $model,
        \Pinpoint\FeaturesManager\Model\FeatureTranslation $featureTranslation,
        \Pinpoint\FeaturesManager\Model\ResourceModel\FeatureTranslation\Collection $featureTranslationCollection,
        \Magento\Framework\Filesystem $filesystem,
        \Magento\Framework\Filesystem\Driver\File $file,
        \Magento\MediaStorage\Model\File\UploaderFactory $fileUploaderFactory
    ) {
        parent::__construct($context);

        $this->_model = $model;
        $this->featureTranslation = $featureTranslation;
        $this->featureTranslationCollection = $featureTranslationCollection;
        $this->filesystem = $filesystem;
        $this->file = $file;
        $this->fileUploaderFactory = $fileUploaderFactory;
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Magento_Catalog::catalog');
    }

    /**
     * Save action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            /** @var \Pinpoint\FeaturesManager\Model\ProductFeatures $model */
            $model = $this->_model;

            $id = $this->getRequest()->getParam('id');
            if ($id && $data['store_id'] === '') {
                $model->load($id);
            } else {
                if ($id){
                    $translation = $this->featureTranslationCollection
                        ->addFieldToFilter('store_id', $data['store_id'])
                        ->addFieldToFilter('feature_id', $id)
                        ->getFirstItem();
                    $data['feature_id'] = $data['id'];
                    unset($data['id']);

                    if ($translation->getId()) {
                        $model = $this->featureTranslation->load($translation->getId());
                        $data['id'] = $model->getId();
                    } else {
                        $model = $this->featureTranslation;
                    }
                }
            }

            if (isset($data['image']) && isset($data['image']['delete'])) {
                $data['image'] = null;
            }

            $model->setData($data);

            try {
                if (get_class($model) === \Pinpoint\FeaturesManager\Model\ProductFeatures::class && !empty($_FILES['image']['tmp_name'])) {
                    $result = $this->uploadImage()['file'];

                    if ($result) {
                        $model->setData('image', 'catalog/product/feature_images' . $result);
                    }
                }

                $model->save();

                $this->messageManager->addSuccess(__('Product Feature saved'));
                $this->_getSession()->setFormData(false);
                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', ['id' => $model->getId(), '_current' => true, 'store' => $this->getRequest()->getParam('store_id')]);
                }
                return $resultRedirect->setPath('*/*/');
            } catch (\Magento\Framework\Exception\LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\RuntimeException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the Product Feature'));
            }

            $this->_getSession()->setFormData($data);
            return $resultRedirect->setPath('*/*/edit', ['id' => $this->getRequest()->getParam('id')]);
        }
        return $resultRedirect->setPath('*/*/');
    }

    /**
     * @return array
     */
    protected function uploadImage()
    {
        $path = $this->filesystem->getDirectoryRead(
            DirectoryList::MEDIA
        )->getAbsolutePath(
            'catalog/product/feature_images/'
        );

        $uploader = $this->fileUploaderFactory->create(['fileId' => 'image']);
        $uploader->setAllowedExtensions(['jpg', 'jpeg', 'png']);
        $uploader->setAllowRenameFiles(true);
        $uploader->setFilesDispersion(true);

        try {
            return $uploader->save($path);
        } catch (\Exception $ex) {
            return ['file' => null];
        }
    }
}
