<?php

namespace Pinpoint\FeaturesManager\Model\Product\Attribute\Source;

/**
 * Class Carousel
 * @package Pinpoint\ProductAttributes\Model\Product\Attribute\Source
 */
class Features extends \Magento\Eav\Model\Entity\Attribute\Source\AbstractSource
{
    /**
     * @var \Magento\Eav\Model\ResourceModel\Entity\AttributeFactory
     */
    protected $_eavAttrEntity;

    /**
     * @var \Pinpoint\FeaturesManager\Model\ResourceModel\ProductFeatures\Collection
     */
    protected $featuresCollection;

    /**
     * Features constructor.
     * @param \Magento\Eav\Model\ResourceModel\Entity\AttributeFactory $eavAttrEntity
     * @param \Pinpoint\FeaturesManager\Model\ResourceModel\ProductFeatures\Collection $featuresCollection
     */
    public function __construct(
        \Magento\Eav\Model\ResourceModel\Entity\AttributeFactory $eavAttrEntity,
        \Pinpoint\FeaturesManager\Model\ResourceModel\ProductFeatures\Collection $featuresCollection
    ) {
        $this->_eavAttrEntity = $eavAttrEntity;
        $this->featuresCollection = $featuresCollection;
    }

    /**
     * getAllOptions
     *
     * @return array
     */
    public function getAllOptions()
    {
        $this->_options = [];

        foreach ($this->featuresCollection->getItems() as $feature) {
            $this->_options[] = [
                'label' => $feature->getName() . ' [ID: ' . $feature->getId() . ']',
                'value' => $feature->getId()
            ];
        }

        return $this->_options;
    }

    /**
     * @return array
     */
    public function getFlatColumns()
    {
        $attributeCode = $this->getAttribute()->getAttributeCode();
        return [
            $attributeCode => [
                'unsigned' => false,
                'default' => null,
                'extra' => null,
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'length' => 255,
                'nullable' => true,
                'comment' => $attributeCode . ' column',
            ],
        ];
    }

    /**
     * @return array
     */
    public function getFlatIndexes()
    {
        $indexes = [];

        $index = 'IDX_' . strtoupper($this->getAttribute()->getAttributeCode());
        $indexes[$index] = ['type' => 'index', 'fields' => [$this->getAttribute()->getAttributeCode()]];

        return $indexes;
    }

    /**
     * @param int $store
     * @return \Magento\Framework\DB\Select|null
     */
    public function getFlatUpdateSelect($store)
    {
        return $this->_eavAttrEntity->create()->getFlatUpdateSelect($this->getAttribute(), $store);
    }
}
