<?php

namespace Pinpoint\FeaturesManager\Ui\DataProvider\Product\Form\Modifier;

use Magento\Catalog\Ui\DataProvider\Product\Form\Modifier\AbstractModifier;
use Magento\Framework\Stdlib\ArrayManager;

/**
 * Class MultiSelect
 * @package Pinpoint\FeaturesManager\Ui\DataProvider\Product\Form\Modifier
 */
class MultiSelect extends AbstractModifier
{
    /**
     * @var Magento\Framework\Stdlib\ArrayManager
     */
    protected $arrayManager;

    /**
     * @param ArrayManager $arrayManager
     */
    public function __construct(
        ArrayManager $arrayManager
    ) {
        $this->arrayManager = $arrayManager;
    }

    /**
     * @param array $meta
     * @return array
     */
    public function modifyMeta(array $meta)
    {
        $fieldCode = 'product_features';
        $elementPath = $this->arrayManager->findPath($fieldCode, $meta, null, 'children');
        $containerPath = $this->arrayManager->findPath(static::CONTAINER_PREFIX . $fieldCode, $meta, null, 'children');
        if (!$elementPath) {
            return $meta;
        }

        $meta = $this->arrayManager->merge(
            $containerPath,
            $meta,
            [
                'children' => [
                    $fieldCode => [
                        'arguments' => [
                            'data' => [
                                'config' => [
                                    'elementTmpl' => 'ui/grid/filters/elements/ui-select',
                                    'component' => 'Magento_Ui/js/form/element/ui-select',
                                    'filterOptions' => true,
                                    'showCheckbox' => true,
                                    'chipsEnabled' => true,
                                    'disableLabel' => true,
                                    'multiple' => true,
                                    'listens' => [
                                        '${ $.namespace }.${ $.namespace }:responseData' => 'setParsed'
                                    ],
                                    'config' => [
                                        'dataScope' => $fieldCode
                                    ]
                                ],
                            ],
                        ],
                    ]
                ]
            ]
        );
        return $meta;
    }

    /**
     * {@inheritdoc}
     */
    public function modifyData(array $data)
    {
        if (isset($data[array_keys($data)[0]]['product']['product_features'])) {
            $values = [];
            $parsed = $data[array_keys($data)[0]]['product']['product_features'];
            if (!is_array($parsed)) {
                $parsed = explode(',', $parsed);
            }

            foreach ($parsed as $value) {
                if ($value !== '') {
                    $values[] = $value;
                }
            }

            $data[array_keys($data)[0]]['product']['product_features'] = $values;
        }
        return $data;
    }
}
